==> haskell-wai-middleware-static-0.9.3-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-middleware-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-middleware-static
version:              0.9.3
visibility:           public
id:                   wai-middleware-static-0.9.3-jWW8hh1V2GJyvPbIarRr9
key:                  wai-middleware-static-0.9.3-jWW8hh1V2GJyvPbIarRr9
license:              BSD-3-Clause
copyright:            (c) 2012-2014 Andrew Farmer
maintainer:           Andrew Farmer <afarmer@ittc.ku.edu>
author:               Andrew Farmer <afarmer@ittc.ku.edu>
stability:            experimental
homepage:             https://github.com/scotty-web/wai-middleware-static
synopsis:             WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.

    [WAI] <http://hackage.haskell.org/package/wai>

category:             Web
abi:                  67c8bdf0a29bed3d6c6ebc9b407100b3
exposed:              True
exposed-modules:      Network.Wai.Middleware.Static
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-middleware-static-0.9.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-middleware-static-0.9.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-middleware-static-0.9.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-middleware-static
hs-libraries:         HSwai-middleware-static-0.9.3-jWW8hh1V2GJyvPbIarRr9
depends:
    base-4.17.2.1 base16-bytestring-1.0.2.0-KDSFpGK70SNFrMbzTIS4T1
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-GRHp3JkMorqFgos3X4dDy6 directory-1.3.7.1
    expiring-cache-map-0.0.6.1-AzVQH3TE7yzL4iSdQE9LFY filepath-1.4.2.2
    http-types-0.12.4-cGP4COhpCbDmQiO5iBXAE
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh text-2.0.2 time-1.12.2
    wai-3.2.4-GUoXUoY24VCBryLqTBaLdB

haddock-interfaces:
    /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-middleware-static-0.9.3-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-middleware-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-middleware-static
version:              0.9.3
visibility:           public
id:                   wai-middleware-static-0.9.3-2aLaHDuVwGqLEuuv0S8Qlj
key:                  wai-middleware-static-0.9.3-2aLaHDuVwGqLEuuv0S8Qlj
license:              BSD-3-Clause
copyright:            (c) 2012-2014 Andrew Farmer
maintainer:           Andrew Farmer <afarmer@ittc.ku.edu>
author:               Andrew Farmer <afarmer@ittc.ku.edu>
stability:            experimental
homepage:             https://github.com/scotty-web/wai-middleware-static
synopsis:             WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.

    [WAI] <http://hackage.haskell.org/package/wai>

category:             Web
abi:                  571cd377310c6124c8d0f586d15a176b
exposed:              True
exposed-modules:      Network.Wai.Middleware.Static
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-middleware-static-0.9.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-middleware-static-0.9.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-middleware-static-0.9.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-middleware-static
hs-libraries:         HSwai-middleware-static-0.9.3-2aLaHDuVwGqLEuuv0S8Qlj
depends:
    base-4.17.2.1 base16-bytestring-1.0.2.0-KDSFpGK70SNFrMbzTIS4T1
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-GRHp3JkMorqFgos3X4dDy6 directory-1.3.7.1
    expiring-cache-map-0.0.6.1-AzVQH3TE7yzL4iSdQE9LFY filepath-1.4.2.2
    http-types-0.12.4-D2DAVTmHvcDBQ0h7IvaEn9
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh text-2.0.2 time-1.12.2
    wai-3.2.4-8wgjzYdHzERLEzwoQEllrh

haddock-interfaces:
    /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
